@@ -1,31 +1,13 @@
-"""
-Modules for making point-defect vacancies
-"""
+"""Modules for making point-defect vacancies."""
 import pprint
-import random
 from collections import OrderedDict
-from jarvis.io.vasp.inputs import Poscar
-from jarvis.core.lattice import Lattice
-from jarvis.core.atoms import Atoms
-import numpy as np
 from jarvis.analysis.structure.spacegroup import Spacegroup3D
-
-
-def rand_select(x=[]):
-    uniq = list(set(x))
-    info = {}
-    for i, ii in enumerate(x):
-        info.setdefault(ii, []).append(i)
-    selected = {}
-    for i, j in info.items():
-        chosen = random.choice(j)
-        selected.setdefault(i, chosen)
-    # print (info)
-    # print (selected)
-    return selected
+from jarvis.core.utils import rand_select
 
 
 class Vacancy(object):
+    """Obtain vacancy defects in Atoms class using Wyckoff data."""
+
     def __init__(
         self,
         atoms=None,
@@ -35,7 +17,19 @@ class Vacancy(object):
         symbol=None,
     ):
         """
-        Get vacancy structures based on Wyckoff positions
+        Initialize the method.
+
+        Arguments are given below.
+        Args:
+            atoms: jarvis.core.Atoms object.
+
+            defect_index: atoms index for defect.
+
+            defect_structure:  Atoms with defect.
+
+            wyckoff_multiplicity: Wyckoff multiplicity.
+
+            symbol: Elemenyt symbol.
         """
         self._atoms = atoms
         self._defect_index = defect_index
@@ -46,6 +40,7 @@ class Vacancy(object):
     def generate_defects(
         self, enforce_c_size=10.0, on_conventional_cell=False, extend=1
     ):
+        """Provide function to generate defects."""
         atoms = self._atoms
         if on_conventional_cell:
             atoms = Spacegroup3D(atoms).conventional_standard_structure
@@ -59,10 +54,6 @@ class Vacancy(object):
             # atoms = atoms.make_supercell([dim1, dim2, dim3])
             supercell_size = [dim1, dim2, dim3]
 
-        element_list = list(set(atoms.elements))
-        #print("s_size=", supercell_size, a, b, c, atoms.lattice.lat_lengths())
-        #print("s_sizeomg=", atoms.pymatgen_converter().lattice.abc)
-        #print(atoms)
         spg = Spacegroup3D(atoms)
         wyckoffs = spg._dataset["wyckoffs"]
         atoms.props = wyckoffs
@@ -82,6 +73,7 @@ class Vacancy(object):
         return vacs
 
     def to_dict(self):
+        """Convert to a dictionary."""
         d = OrderedDict()
         d["atoms"] = self._atoms
         d["defect_structure"] = self._defect_structure
@@ -91,11 +83,13 @@ class Vacancy(object):
         return d
 
     def __repr__(self, indent=2):
+        """Representation of the class as dict."""
         return pprint.pformat(self.to_dict(), indent=indent)
 
 
 """
 if __name__ == "__main__":
+    from jarvis.io.vasp.inputs import Poscar
 
     box = [[2.715, 2.715, 0], [0, 2.715, 2.715], [2.715, 0, 2.715]]
     coords = [[0, 0, 0], [0.25, 0.25, 0.25]]
