@@ -11,8 +11,12 @@ class LammpsData(object):
     """Construct Lammps data file."""
 
     def __init__(
-        self, lammps_box=[], species=[],
-        charges=[], cart_coords=[], element_order=[]
+        self,
+        lammps_box=[],
+        species=[],
+        charges=[],
+        cart_coords=[],
+        element_order=[],
     ):
         """Provide following information."""
         self._lammps_box = lammps_box
@@ -40,8 +44,10 @@ class LammpsData(object):
         )
         elements = [self._element_order[i - 1] for i in self._species]
         atoms = Atoms(
-            lattice_mat=lat, elements=elements,
-            coords=self._cart_coords, cartesian=True
+            lattice_mat=lat,
+            elements=elements,
+            coords=self._cart_coords,
+            cartesian=True,
         )
         return atoms
 
@@ -86,13 +92,14 @@ class LammpsData(object):
     def read_data(
         self,
         filename="lammps.data",
-        element_order=["O", "Al"],
+        element_order=[],
         potential_file="pot.mod",
     ):
         """Read Lammps data file."""
         # n_atoms = len(self._species)
         if element_order == []:
             # Reading potential file for element order
+            print('element_order is empty, reading from', potential_file)
             pot_file = open(potential_file, "r")
             lines = pot_file.read().splitlines()
             pot_file.close()
@@ -139,8 +146,9 @@ class LammpsData(object):
                 xz = float(line.split()[1])
                 yz = float(line.split()[2])
         if len(symb) != ntypes:
-            ValueError("Something wrong in atom type assignment",
-                       len(symb), ntypes)
+            ValueError(
+                "Something wrong in atom type assignment", len(symb), ntypes
+            )
         lat = np.array(
             [[xhi - xlo, 0.0, 0.0], [xy, yhi - ylo, 0.0], [xz, yz, zhi - zlo]]
         )
@@ -165,8 +173,10 @@ class LammpsData(object):
         typ_sp = [str(i, "utf-8") for i in typ]
         # print ('typ_sp',typ_sp)
         atoms = Atoms(
-            lattice_mat=lat, elements=typ_sp,
-            coords=np.array(coords), cartesian=True
+            lattice_mat=lat,
+            elements=typ_sp,
+            coords=np.array(coords),
+            cartesian=True,
         )
         return atoms
 
@@ -200,8 +210,9 @@ class LammpsData(object):
             s = self._species[i]
             r = self._cart_coords[i]
             charge = self._charges[i]
-            f.write("%6d %3d %6f %s %s %s\n" % (i + 1,
-                    s, charge, r[0], r[1], r[2]))
+            f.write(
+                "%6d %3d %6f %s %s %s\n" % (i + 1, s, charge, r[0], r[1], r[2])
+            )
         f.close()
 
     def to_dict(self):
@@ -211,20 +222,20 @@ class LammpsData(object):
         d["box"] = self._lammps_box
         d["species"] = self._species
         d["charges"] = self._charges
-        d["cart_coords"] = self._charges
+        d["cart_coords"] = self._cart_coords
         d["element_order"] = self._element_order
         return d
 
-    # def from_dict(self):
-
-        d["box"] = self._lammps_box
-        d["species"] = self._species
-        d["charges"] = self._charges
-        d["cart_coords"] = self._charges
-        d["element_order"] = self._element_order
-        return d
-
-    # def from_dict(self):
+    @classmethod
+    def from_dict(self, d={}):
+        """Construct from a dictionary."""
+        return LammpsData(
+            lammps_box=d["box"],
+            species=d["species"],
+            charges=d["charges"],
+            cart_coords=d["cart_coords"],
+            element_order=d["element_order"],
+        )
 
     def __repr__(self, indent=4):
         """Print method."""
@@ -334,7 +345,8 @@ class LammpsInput(object):
             # default interaction
             f.write(
                 "pair_style lj/cut 2.5 \n"
-                + "pair_coeff * * 1 1 \n" + "mass * 1.0 \n"
+                + "pair_coeff * * 1 1 \n"
+                + "mass * 1.0 \n"
             )
         f1.write("neighbor 1.0 nsq\n")
         f1.write("neigh_modify once no every 1 delay 0 check yes\n")
