@@ -6,22 +6,37 @@ from jarvis.analysis.structure.spacegroup import (
 from jarvis.core.atoms import Atoms
 from jarvis.io.vasp.inputs import Poscar
 import os
+from collections import defaultdict
 
 s1 = Poscar.from_file(
     os.path.join(os.path.dirname(__file__), "..", "defects", "POSCAR-667.vasp")
 ).atoms
 s2 = Poscar.from_file(
-    os.path.join(os.path.dirname(__file__), "..", "..", "io", "wannier", "POSCAR")
+    os.path.join(
+        os.path.dirname(__file__), "..", "..", "io", "wannier", "POSCAR"
+    )
 ).atoms
 s3 = Poscar.from_file(
     os.path.join(os.path.dirname(__file__), "POSCAR-tetragonal")
 ).atoms
-s4 = Poscar.from_file(os.path.join(os.path.dirname(__file__), "POSCAR-Cmcm")).atoms
-s5 = Poscar.from_file(os.path.join(os.path.dirname(__file__), "POSCAR-Aem2")).atoms
-s6 = Poscar.from_file(os.path.join(os.path.dirname(__file__), "POSCAR-C2m")).atoms
-s7 = Poscar.from_file(os.path.join(os.path.dirname(__file__), "POSCAR-Pc")).atoms
-s8 = Poscar.from_file(os.path.join(os.path.dirname(__file__), "POSCAR-P-1")).atoms
-s9 = Poscar.from_file(os.path.join(os.path.dirname(__file__), "POSCAR-P21m")).atoms
+s4 = Poscar.from_file(
+    os.path.join(os.path.dirname(__file__), "POSCAR-Cmcm")
+).atoms
+s5 = Poscar.from_file(
+    os.path.join(os.path.dirname(__file__), "POSCAR-Aem2")
+).atoms
+s6 = Poscar.from_file(
+    os.path.join(os.path.dirname(__file__), "POSCAR-C2m")
+).atoms
+s7 = Poscar.from_file(
+    os.path.join(os.path.dirname(__file__), "POSCAR-Pc")
+).atoms
+s8 = Poscar.from_file(
+    os.path.join(os.path.dirname(__file__), "POSCAR-P-1")
+).atoms
+s9 = Poscar.from_file(
+    os.path.join(os.path.dirname(__file__), "POSCAR-P21m")
+).atoms
 
 
 def test_spg():
@@ -85,4 +100,10 @@ def test_spg():
     assert spg.space_group_number == 11
 
 
+def test_all_spgs():
+    """Moved to K-points module because of duplication."""
+    return True
+
+
+# test_all_spgs()
 # test_spg()
